summaryrefslogtreecommitdiffstats
path: root/ash/shell_observer.h
diff options
context:
space:
mode:
authormukai@chromium.org <mukai@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-12-17 19:21:18 +0000
committermukai@chromium.org <mukai@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-12-17 19:21:18 +0000
commitf89f751c3504095593e99170392dc361b1dbf0cc (patch)
tree11def2b2ad64c8afe6416b149828379d667affd1 /ash/shell_observer.h
parent5d5a35d75f4f9e514895da35b79816ea2f7ab618 (diff)
downloadchromium_src-f89f751c3504095593e99170392dc361b1dbf0cc.zip
chromium_src-f89f751c3504095593e99170392dc361b1dbf0cc.tar.gz
chromium_src-f89f751c3504095593e99170392dc361b1dbf0cc.tar.bz2
Enables storing shelf's auto_hide_behavior and alignment per display.
BUG=165419 TEST=on a dev-mode device, change the launcher's auto-hide behavior and see how it's stored in Preferences Review URL: https://codereview.chromium.org/11570017 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@173508 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/shell_observer.h')
-rw-r--r--ash/shell_observer.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/ash/shell_observer.h b/ash/shell_observer.h
index 6cbeaa7..0bdd934 100644
--- a/ash/shell_observer.h
+++ b/ash/shell_observer.h
@@ -8,6 +8,10 @@
#include "ash/ash_export.h"
#include "ash/system/user/login_status.h"
+namespace aura {
+class RootWindow;
+}
+
namespace ash {
class ASH_EXPORT ShellObserver {
@@ -25,8 +29,8 @@ class ASH_EXPORT ShellObserver {
// unlocked.
virtual void OnLockStateChanged(bool locked) {}
- // Invoked when the shelf alignment is changed.
- virtual void OnShelfAlignmentChanged() {}
+ // Invoked when the shelf alignment in |root_window| is changed.
+ virtual void OnShelfAlignmentChanged(aura::RootWindow* root_window) {}
protected:
virtual ~ShellObserver() {}